# -*- coding: utf-8 -*-
"""Init and utils."""

import logging

logger = logging.getLogger('collective.pamfixes')

logger.warning(
    'Patching alternate languages viewlet for plone.app.multilingual.'
)
